// src/index.ts
import { getCompatContextProvider } from "react-querybuilder";

// src/BootstrapDragHandle.tsx
import { forwardRef } from "react";
import { jsx } from "react/jsx-runtime";
var BootstrapDragHandle = forwardRef(
  ({ className, title }, dragRef) => /* @__PURE__ */ jsx("span", { ref: dragRef, className, title, children: /* @__PURE__ */ jsx("i", { className: "bi bi-grip-vertical" }) })
);
BootstrapDragHandle.displayName = "BootstrapDragHandle";

// src/BootstrapNotToggle.tsx
import { useId } from "react";
import { jsx as jsx2, jsxs } from "react/jsx-runtime";
var BootstrapNotToggle = ({
  className,
  handleOnChange,
  title,
  label,
  checked,
  disabled
}) => {
  const id = useId();
  return /* @__PURE__ */ jsxs("div", { className: `form-check-inline form-switch ${className}`, children: [
    /* @__PURE__ */ jsx2(
      "input",
      {
        id,
        className: "form-check-input",
        type: "checkbox",
        onChange: (e) => handleOnChange(e.target.checked),
        checked: !!checked,
        disabled
      }
    ),
    /* @__PURE__ */ jsx2("label", { title, htmlFor: id, className: "form-check-label", children: label })
  ] });
};
BootstrapNotToggle.displayName = "BootstrapNotToggle";

// src/BootstrapValueEditor.tsx
import {
  getFirstOption,
  standardClassnames,
  useValueEditor,
  ValueEditor,
  ValueSelector
} from "react-querybuilder";
import { jsx as jsx3, jsxs as jsxs2 } from "react/jsx-runtime";
import { createElement } from "react";
var BootstrapValueEditor = (props) => {
  const { valueAsArray, multiValueHandler } = useValueEditor({
    handleOnChange: props.handleOnChange,
    inputType: props.inputType,
    operator: props.operator,
    value: props.value,
    type: props.type,
    listsAsArrays: props.listsAsArrays,
    parseNumbers: props.parseNumbers,
    values: props.values
  });
  const { selectorComponent: SelectorComponent = ValueSelector } = props;
  if (props.operator === "null" || props.operator === "notNull") {
    return null;
  }
  const placeHolderText = props.fieldData?.placeholder ?? "";
  if ((props.operator === "between" || props.operator === "notBetween") && (props.type === "select" || props.type === "text")) {
    const editors = ["from", "to"].map((key, i) => {
      if (props.type === "text") {
        return /* @__PURE__ */ jsx3(
          "input",
          {
            type: props.inputType || "text",
            placeholder: placeHolderText,
            value: valueAsArray[i] ?? "",
            className: `${standardClassnames.valueListItem} form-control form-control-sm`,
            disabled: props.disabled,
            onChange: (e) => multiValueHandler(e.target.value, i)
          },
          key
        );
      }
      return /* @__PURE__ */ createElement(
        SelectorComponent,
        {
          ...props,
          key,
          className: `${standardClassnames.valueListItem} form-select form-select-sm`,
          handleOnChange: (v) => multiValueHandler(v, i),
          disabled: props.disabled,
          value: valueAsArray[i] ?? getFirstOption(props.values),
          options: props.values ?? [],
          listsAsArrays: props.listsAsArrays
        }
      );
    });
    return /* @__PURE__ */ jsxs2("span", { "data-testid": props.testID, className: standardClassnames.value, title: props.title, children: [
      editors[0],
      props.separator,
      editors[1]
    ] });
  }
  switch (props.type) {
    case "select":
    case "multiselect":
      return /* @__PURE__ */ jsx3(
        ValueEditor,
        {
          skipHook: true,
          ...props,
          className: `${props.className} form-select form-select-sm`
        }
      );
    case "switch":
      return /* @__PURE__ */ jsx3("span", { className: `custom-control custom-switch ${props.className}`, children: /* @__PURE__ */ jsx3(
        "input",
        {
          type: "checkbox",
          className: "form-check-input custom-control-input",
          title: props.title,
          disabled: props.disabled,
          onChange: (e) => props.handleOnChange(e.target.checked),
          checked: !!props.value
        }
      ) });
    case "checkbox":
      return /* @__PURE__ */ jsx3(ValueEditor, { skipHook: true, ...props, className: `form-check-input ${props.className}` });
    case "radio":
      return /* @__PURE__ */ jsx3("span", { title: props.title, className: standardClassnames.value, children: props.values?.map((v) => /* @__PURE__ */ jsxs2("div", { className: "form-check form-check-inline", children: [
        /* @__PURE__ */ jsx3(
          "input",
          {
            className: "form-check-input",
            type: "radio",
            id: v.name,
            value: v.name,
            checked: props.value === v.name,
            disabled: props.disabled,
            onChange: (e) => props.handleOnChange(e.target.value)
          }
        ),
        /* @__PURE__ */ jsx3("label", { className: "form-check-label", htmlFor: v.name, children: v.label })
      ] }, v.name)) });
  }
  return /* @__PURE__ */ jsx3(ValueEditor, { skipHook: true, ...props });
};
BootstrapValueEditor.displayName = "BootstrapValueEditor";

// src/index.ts
var bootstrapControlElements = {
  dragHandle: BootstrapDragHandle,
  notToggle: BootstrapNotToggle,
  valueEditor: BootstrapValueEditor
};
var bootstrapControlClassnames = {
  addGroup: "btn btn-secondary btn-sm",
  addRule: "btn btn-primary btn-sm",
  cloneGroup: "btn btn-secondary btn-sm",
  cloneRule: "btn btn-secondary btn-sm",
  lockGroup: "btn btn-secondary btn-sm",
  lockRule: "btn btn-secondary btn-sm",
  removeGroup: "btn btn-danger btn-sm",
  removeRule: "btn btn-danger btn-sm",
  combinators: "form-select form-select-sm",
  fields: "form-select form-select-sm",
  operators: "form-select form-select-sm",
  value: "form-control form-control-sm",
  valueSource: "form-select form-select-sm"
};
var QueryBuilderBootstrap = getCompatContextProvider({
  key: "bootstrap",
  controlClassnames: bootstrapControlClassnames,
  controlElements: bootstrapControlElements
});
export {
  BootstrapDragHandle,
  BootstrapNotToggle,
  BootstrapValueEditor,
  QueryBuilderBootstrap,
  bootstrapControlClassnames,
  bootstrapControlElements
};
//# sourceMappingURL=react-querybuilder_bootstrap.mjs.map